==> image-editor_1.0.11.orig.tar.xz: image-editor-1.0.11/libimageviewer/translations/libimageviewer_lt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="lt" version="2.1">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Paveikslo informacija</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Pagrindinė informacija</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Išsamiau</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Pridėti į albumą</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Naujas albumas</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Visi paveikslai</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Atverti paveikslą</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Šalinti iš albumo</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nebemėgstamas</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Mėgstamas</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Jūs neturite leidimų peržiūrėti paveikslą</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Pavadinimas</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipas</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Keitimo data</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Failo dydis</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Fotografavimo data</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Išlaikymo veiksena</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Išlaikymo programa</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Išlaikymas</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Blykstė</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Diafragma</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Židinio nuotolis</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Didžiausia diafragma</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Matavimo veiksena</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Baltos spalvos balansas</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Blykstės kompensavimas</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Objektyvo modelis</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Spalvų erdvė</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Fotoaparato modelis</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Matmenys</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Žymė</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Atgal</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Ankstesnis</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Kitas</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Dydis 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Talpinti į langą</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Pasukti prieš laikrodžio rodyklę</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Pasukti pagal laikrodžio rodyklę</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Išeiti iš viso ekrano</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Visas ekranas</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Spausdinti</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Skaidrių rodymas</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopijuoti</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Pervadinti</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Rodyti naršymo langą</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Slėpti naršymo langą</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nustatyti kaip darbalaukio foną</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Rodyti failų tvarkytuvėje</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Paveikslo informacija</translation>
    </message>
    <message>
        <source>day</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Patvirtinti</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Įveskite naują pavadinimą</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Ankstesnis</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pristabdyti</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Paleisti</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Kitas</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Išeiti</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Nerasta jokių paveikslo failų</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Paveikslas nerastas</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> image-editor_1.0.18.orig.tar.xz: image-editor-1.0.18/libimageviewer/translations/libimageviewer_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Paveikslo informacija</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Pagrindinė informacija</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Išsamiau</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Pridėti į albumą</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Naujas albumas</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Visi paveikslai</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Atverti paveikslą</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Šalinti iš albumo</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Nebemėgstamas</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Mėgstamas</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Jūs neturite leidimų peržiūrėti paveikslą</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Pavadinimas</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipas</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Keitimo data</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Failo dydis</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Fotografavimo data</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Išlaikymo veiksena</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Išlaikymo programa</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Išlaikymas</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Blykstė</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Diafragma</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Židinio nuotolis</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Didžiausia diafragma</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Matavimo veiksena</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Baltos spalvos balansas</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Blykstės kompensavimas</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Objektyvo modelis</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Spalvų erdvė</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Fotoaparato modelis</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Matmenys</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Žymė</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Atgal</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Ankstesnis</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Kitas</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Dydis 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Talpinti į langą</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Pasukti prieš laikrodžio rodyklę</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Pasukti pagal laikrodžio rodyklę</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Išeiti iš viso ekrano</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Visas ekranas</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Spausdinti</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Skaidrių rodymas</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopijuoti</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Pervadinti</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Rodyti naršymo langą</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Slėpti naršymo langą</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nustatyti kaip darbalaukio foną</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Rodyti failų tvarkytuvėje</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Paveikslo informacija</translation>
    </message>
    <message>
        <source>day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Patvirtinti</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Įveskite naują pavadinimą</translation>
    </message>
    <message>
        <source>The file already exists, please use another name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Ankstesnis</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pristabdyti</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Paleisti</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Kitas</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Išeiti</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Nerasta jokių paveikslo failų</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Paveikslas nerastas</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
